@@ -114,7 +114,7 @@ class Consumer():
             if queues[queue] not in self.inbound_queues.values():
                 self.putEvent(deepcopy(event), queues[queue])
                 if self.enable_trace:
-                    print "Module {0} putting event on queue {1}".format(self.name, queue)
+                    self.logging.debug("Module {0} putting event on queue {1}".format(self.name, queue))
 
 
     def putEvent(self, event, destination):
@@ -174,7 +174,7 @@ class Consumer():
                 try:
                     fc(event, origin=q.name)
                     if self.enable_trace:
-                        print "Module {0} received event on queue {1}".format(self.name, q.name)
+                        self.logging.debug("Module {0} received event on queue {1}".format(self.name, q.name))
                 except TypeError as err:
                     self.logging.warn("You must define a consume function as consume(self, event, *args, **kwargs): {0}".format(err))
                     traceback.print_exc()
